@@ -24,6 +24,8 @@
 #include "libgraphtheory/editor.h"
 #include <KConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KTextEditor/Document>
 #include <KTextEditor/Editor>
 #include <KTar>
@@ -123,6 +125,7 @@ bool ProjectPrivate::loadProject(const QUrl &url)
     }
     m_journal = KTextEditor::Editor::instance()->createDocument(nullptr);
     m_journal->openUrl(QUrl::fromLocalFile(m_workingDirectory.path() + QChar('/') + metaInfo["journal.txt"].toString()));
+    Q_ASSERT(m_journal != nullptr);
 
     //TODO save & load open document index
 
@@ -179,7 +182,15 @@ Project::Project(const QUrl &projectFile, GraphTheory::Editor *graphEditor)
 {
     d->m_graphEditor = graphEditor;
     d->m_projectUrl = projectFile;
-    d->loadProject(projectFile);
+    if (!d->loadProject(projectFile)) {
+        addGraphDocument(graphEditor->createDocument());
+        setModified(false);
+        d->m_journal = KTextEditor::Editor::instance()->createDocument(nullptr);
+
+        KMessageBox::error(nullptr,
+                           i18nc("@info",
+                                 "The Rocs project could not be imported because the project file could not be parsed."));
+    }
 
     for (const auto &document : d->m_codeDocuments) {
         connect(document, &KTextEditor::Document::modifiedChanged,
@@ -210,26 +221,41 @@ QString Project::workingDir() const
     return d->m_workingDirectory.path();
 }
 
-bool Project::addCodeDocument(KTextEditor::Document *document)
+KTextEditor::Document* Project::createCodeDocument(const QString& filePath)
 {
-    // compute first unused document path
-    QStringList usedPaths;
-    foreach (KTextEditor::Document *document, d->m_codeDocuments) {
-        usedPaths.append(document->url().toLocalFile());
-    }
-    QString path;
-    for (int i = 0; i <= d->m_codeDocuments.count(); ++i) {
-        path = d->m_workingDirectory.path()
-            + QChar('/')
-            + "codefile" + QString::number(i) + QString(".js");
-        if (!usedPaths.contains(path)) {
-            break;
-        }
+    auto path = d->m_workingDirectory.path() + QLatin1Char('/') + filePath + QStringLiteral(".js");
+
+    auto doc = KTextEditor::Editor::instance()->createDocument(nullptr);
+    if (!doc->saveAs(QUrl::fromLocalFile(path))) {
+        qCritical() << "Error when saving code file to working directory, aborting.";
+        return nullptr;
     }
 
-    // put document into working directory
-    if (!document->saveAs(QUrl::fromLocalFile(path))) {
-        qCritical() << "Error when saving code file to working directory, aborting.";
+    if (!addCodeDocument(doc)) {
+        return nullptr;
+    }
+
+    return doc;
+}
+
+KTextEditor::Document* Project::openCodeDocument(const QUrl &url)
+{
+    auto doc = KTextEditor::Editor::instance()->createDocument(nullptr);
+    if (!doc->openUrl(url)) {
+        qCritical() << "Error when opening code file, aborting.";
+        return nullptr;
+    }
+
+    if (!addCodeDocument(doc)) {
+        return nullptr;
+    }
+
+    return doc;
+}
+
+bool Project::addCodeDocument(KTextEditor::Document *document)
+{
+    if (document == nullptr) {
         return false;
     }
 
@@ -244,16 +270,14 @@ bool Project::addCodeDocument(KTextEditor::Document *document)
 
 KTextEditor::Document * Project::importCodeDocument(const QUrl &url)
 {
-    KTextEditor::Document *document = KTextEditor::Editor::instance()->createDocument(nullptr);
-    document->openUrl(url);
-    addCodeDocument(document);
-    return document;
+    return openCodeDocument(url);
 }
 
-void Project::removeCodeDocument(KTextEditor::Document *document)
+void Project::tryToRemoveCodeDocument(KTextEditor::Document *document)
 {
     QString path = document->url().toString();
-    document->closeUrl();
+    if(!document->closeUrl())
+        return;
     int index = d->m_codeDocuments.indexOf(document);
     emit codeDocumentAboutToBeRemoved(index, index);
     disconnect(document, &KTextEditor::Document::modifiedChanged,
@@ -448,7 +472,7 @@ bool Project::isModified() const
             return true;
         }
     }
-    if (d->m_journal->isModified()) {
+    if (d->m_journal && d->m_journal->isModified()) {
         return true;
     }
 
